@@ -324,14 +324,14 @@ kax_reader_c::packets_available() {
 kax_track_t *
 kax_reader_c::find_track_by_num(uint64_t n,
                                 kax_track_t *c) {
-  auto itr = brng::find_if(m_tracks, [&](kax_track_cptr &track) { return (track->track_number == n) && (track.get() != c); });
+  auto itr = brng::find_if(m_tracks, [n, c](auto &track) { return (track->track_number == n) && (track.get() != c); });
   return itr == m_tracks.end() ? nullptr : itr->get();
 }
 
 kax_track_t *
 kax_reader_c::find_track_by_uid(uint64_t uid,
                                 kax_track_t *c) {
-  auto itr = brng::find_if(m_tracks, [&](kax_track_cptr &track) { return (track->track_uid == uid) && (track.get() != c); });
+  auto itr = brng::find_if(m_tracks, [uid, c](auto &track) { return (track->track_uid == uid) && (track.get() != c); });
   return itr == m_tracks.end() ? nullptr : itr->get();
 }
 
@@ -661,7 +661,7 @@ kax_reader_c::verify_hdmv_textst_subtitle_track(kax_track_t *t) {
   auto style_segment_start = old_style ? 1 : 0;
   auto style_segment_size  = get_uint16_be(&buf[style_segment_start + 1]);
 
-  if (t->private_size < (3 + style_segment_size + (old_style ? 1 + 2 : 0))) {
+  if (t->private_size < static_cast<unsigned int>(3 + style_segment_size + (old_style ? 1 + 2 : 0))) {
     mxwarn(boost::format(Y("matroska_reader: The CodecID for track %1% is '%2%', but the private codec data does not contain valid headers.\n")) % t->codec_id);
     return false;
   }
@@ -784,7 +784,7 @@ kax_reader_c::handle_attachments(mm_io_c *io,
     return;
 
   io->save_pos(pos);
-  at_scope_exit_c restore([&]() { io->restore_pos(); });
+  at_scope_exit_c restore([io]() { io->restore_pos(); });
 
   int upper_lvl_el = 0;
   std::shared_ptr<EbmlElement> l1(m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true));
@@ -840,7 +840,7 @@ kax_reader_c::handle_chapters(mm_io_c *io,
     return;
 
   io->save_pos(pos);
-  at_scope_exit_c restore([&]() { io->restore_pos(); });
+  at_scope_exit_c restore([io]() { io->restore_pos(); });
 
   int upper_lvl_el = 0;
   std::shared_ptr<EbmlElement> l1(m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true));
@@ -872,7 +872,7 @@ kax_reader_c::handle_tags(mm_io_c *io,
     return;
 
   io->save_pos(pos);
-  at_scope_exit_c restore([&]() { io->restore_pos(); });
+  at_scope_exit_c restore([io]() { io->restore_pos(); });
 
   int upper_lvl_el = 0;
   std::shared_ptr<EbmlElement> l1(m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true));
@@ -953,7 +953,7 @@ kax_reader_c::read_headers_info(mm_io_c *io,
     return;
 
   io->save_pos(pos);
-  at_scope_exit_c restore([&]() { io->restore_pos(); });
+  at_scope_exit_c restore([io]() { io->restore_pos(); });
 
   int upper_lvl_el = 0;
   std::shared_ptr<EbmlElement> l1(m_es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true));
@@ -1270,7 +1270,7 @@ kax_reader_c::handle_seek_head(mm_io_c *io,
     return;
 
   std::vector<int64_t> next_seek_head_positions;
-  at_scope_exit_c restore([&]() { io->restore_pos(); });
+  at_scope_exit_c restore([io]() { io->restore_pos(); });
 
   try {
     io->save_pos(pos);
@@ -1979,7 +1979,7 @@ kax_reader_c::create_packetizers() {
   for (auto &track : m_tracks)
     create_packetizer(track->tnum);
 
-  if (!g_segment_title_set) {
+  if (!g_segment_title_set && !m_title.empty()) {
     g_segment_title     = m_title;
     g_segment_title_set = true;
   }
@@ -2017,7 +2017,7 @@ kax_reader_c::create_vc1_video_packetizer(kax_track_t *t,
   read_first_frames(t, 1);
   if (   !t->first_frames_data.empty()
       && (4 <= t->first_frames_data[0]->get_size())
-      && !vc1::is_marker(get_uint32_be(t->first_frames_data[0]->get_buffer()))) {
+      && !mtx::vc1::is_marker(get_uint32_be(t->first_frames_data[0]->get_buffer()))) {
     init_passthrough_packetizer(t, nti);
     return;
   }
