@@ -28,6 +28,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
   , ui{new Ui::PreferencesDialog}
   , m_cfg(Util::Settings::get())
   , m_previousUiLocale{m_cfg.m_uiLocale}
+  , m_previousProbeRangePercentage{m_cfg.m_probeRangePercentage}
 {
   ui->setupUi(this);
 
@@ -112,6 +113,12 @@ PreferencesDialog::uiLocaleChanged()
   return m_previousUiLocale != m_cfg.m_uiLocale;
 }
 
+bool
+PreferencesDialog::probeRangePercentageChanged()
+  const {
+  return m_previousProbeRangePercentage != m_cfg.m_probeRangePercentage;
+}
+
 void
 PreferencesDialog::pageSelectionChanged(QModelIndex const &current) {
   if (!current.isValid())
